package jp.co.intra_mart.data_migration.generator.isp61;

import java.io.IOException;
import java.io.Writer;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;

import jp.co.intra_mart.data_migration.InsertFileWriter;
import jp.co.intra_mart.data_migration.common.BMCommon;
import jp.co.intra_mart.data_migration.common.initialContext;
import jp.co.intra_mart.data_migration.common.read.CreateRowsException;
import jp.co.intra_mart.data_migration.common.read.Rows;
import jp.co.intra_mart.data_migration.common.read.database.DatabaseReader;
import jp.co.intra_mart.data_migration.common.table.ColumnInfo;
import jp.co.intra_mart.data_migration.common.table.GeneratorConstant;
import jp.co.intra_mart.data_migration.common.table.ISPGeneratorAdaptor;
import jp.co.intra_mart.data_migration.common.util.StringUtil;

public class BulletinGenerator extends ISPGeneratorAdaptor {

	Rows rows = null;

	private static final ColumnInfo[] COLUMNSBINFO = {
		/* ISPT_BULLETIN_INFO
		 * 
			fʃR[h (FK)	BULLETIN_CLS_CD		VARCHAR2	20	0	Y	
			fR[h			BULLETIN_INFO_CD	VARCHAR2	20	0	Y	1
			XbhR[h			THREAD_CD			VARCHAR2	20	0	Y	
			^Cg				TITLE				VARCHAR2	255	0	Y	
			e					CONTENTS			VARCHAR2	2000	0		
			HTMLRec			CONTENTS_HTML		VARCHAR2	2000	0		
			zM				NOTICE_CLS_CD		VARCHAR2	3	0		
			zMJn			NOTICE_START_DATE	VARCHAR2	19	0		
			zMI			NOTICE_END_DATE		VARCHAR2	19	0		
			o^[UR[h			INSERT_USER_CD		VARCHAR2	50	0	Y	
			o^[U			INSERT_USER_NAME	VARCHAR2	128	0	Y	
			o^				INSERT_DATE			VARCHAR2	19	0	Y	
			XV[UR[h			RECORD_USER_CD		VARCHAR2	50	0	Y	
			XV[U			RECORD_USER_NAME	VARCHAR2	128	0	Y	
			XV				RECORD_DATE			VARCHAR2	19	0	Y	
			fڊԊJn			START_DATE			VARCHAR2	19	0		
			fڊԏI			END_DATE			VARCHAR2	19	0		
		 */
		// fʃR[h
		new ColumnInfo("bulletin_cls_cd", "varchar2(20)", false, false, false, false), 
		// fR[h
		new ColumnInfo("bulletin_info_cd", "varchar2(20)", true, false, false, false), 
		// XbhR[h
		new ColumnInfo("thread_cd", "varchar2(20)", false, false, false, false), 
		// ^Cg
		new ColumnInfo("title", "varchar2(255)", false, false, false, false), 
		// e
		new ColumnInfo("contents", "varchar2(2000)", false, false, false, true), 
		// HTMLRec
		new ColumnInfo("contents_html", "varchar2(2000)", false, false, false, true), 
		// zM
		new ColumnInfo("notice_cls_cd", "varchar2(3)", false, false, false, true), 
		// zMJn
		new ColumnInfo("notice_start_date", "varchar2(19)", false, false, false, true), 
		// zMI
		new ColumnInfo("notice_end_date", "varchar2(19)", false, false, false, true), 
		// o^[UR[h
		new ColumnInfo("insert_user_cd", "varchar2(50)", false, false, false, false), 
		// o^[U
		new ColumnInfo("insert_user_name", "varchar2(128)", false, false, false, false), 
		// o^
		new ColumnInfo("insert_date", "varchar2(19)", false, false, false, false), 
		// XV[UR[h
		new ColumnInfo("record_user_cd", "varchar2(50)", false, false, false, false), 
		// XV[U
		new ColumnInfo("record_user_name", "varchar2(128)", false, false, false, false), 
		// XV
		new ColumnInfo("record_date", "varchar2(19)", false, false, false, false), 
		// fڊԊJn
		new ColumnInfo("start_date", "varchar2(19)", false, false, false, true), 
		// fڊԏI
		new ColumnInfo("end_date", "varchar2(19)", false, false, false, true), 
	};

	public void createSQLFile(Writer out, Connection connection) throws IOException {

		DatabaseReader databaseReader = new DatabaseReader();

		PreparedStatement statement = null;
		StringBuffer sqlBuffer = new StringBuffer();
		// ISPT_BULLETIN_INFO f[^擾
		sqlBuffer.append("SELECT T1.bulletin_cls_cd, ");	// 1
		sqlBuffer.append("T1.bulletin_info_cd, ");			// 2
		sqlBuffer.append("T1.thread_cd, ");					// 3
		sqlBuffer.append("T1.title, ");						// 4
		sqlBuffer.append("T1.contents, ");					// 5
		sqlBuffer.append("T1.contents_html, ");				// 6
		sqlBuffer.append("T1.notice_cls_cd, ");				// 7
		sqlBuffer.append("T1.notice_start_date, ");			// 8
		sqlBuffer.append("T1.notice_end_date, ");			// 9
		sqlBuffer.append("T1.insert_user_cd, ");			// 10
		sqlBuffer.append("T1.insert_user_name, ");			// 11
		sqlBuffer.append("T1.insert_date, ");				// 12
		sqlBuffer.append("T1.record_user_cd, ");			// 13
		sqlBuffer.append("T1.record_user_name, ");			// 14
		sqlBuffer.append("T1.record_date, ");				// 15
		sqlBuffer.append("T1.start_date, ");				// 16
		sqlBuffer.append("T1.end_date ");					// 17
		sqlBuffer.append("FROM ispt_bulletin_info T1");					

		try {
			statement = connection.prepareStatement(sqlBuffer.toString());
		} catch (SQLException e1) {
			// TODO Auto-generated catch block
			e1.printStackTrace();
		}
		try {
			rows =  databaseReader.read(connection, statement);
		} catch (CreateRowsException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (SQLException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		COLUMNS =  COLUMNSBINFO;
		String insertSQLFacility = createInsertBaseSQL();

		// ispt_bulletin_infõt@CC^[
		InsertFileWriter bulletinWriter = new InsertFileWriter();
		bulletinWriter.setTableName("ispt_bulletin_info");

		StringBuffer bulletinBuffer;

		for (int i = 1; i < rows.size()+1; i++) {
			
			bulletinBuffer = new StringBuffer();

			// insert
			bulletinBuffer.append(insertSQLFacility);
			
			// bulletin_cls_cd
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(1)) + ", ");
			
			// bulletin_info_cd
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(2)) + ", ");
			
			// thread_cd
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(3)) + ", ");
			
			// title
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(4)) + ", ");
			
			// contents
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(5)) + ", ");
			
			// contents_html
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(6)) + ", ");
			
			// notice_cls_cd
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(7)) + ", ");
			
			// notice_start_date
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(8)) + ", ");
			
			// notice_end_date
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(9)) + ", ");
			
			// insert_user_cd
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(10)) + ", ");
			
			// insert_user_name
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(11)) + ", ");
			
			// insert_date
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(12)) + ", ");
			
			// record_user_cd
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(13)) + ", ");
			
			// record_user_name
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(14)) + ", ");
			
			// record_date
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(15)) + ", ");
			
			// start_date
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(16)) + ", ");
			
			// end_date
			bulletinBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(17)) + ");\n");
			
			bulletinWriter.addRecord(bulletinBuffer.toString());

		}

		bulletinWriter.close();
	}

	ColumnInfo[] COLUMNS = null;

	public ColumnInfo[] getColumnInfos() {
		return COLUMNS;
	}

}
