package jp.co.intra_mart.data_migration.generator.isp61;

import java.io.IOException;
import java.io.Writer;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;

import jp.co.intra_mart.data_migration.InsertFileWriter;
import jp.co.intra_mart.data_migration.common.BMCommon;
import jp.co.intra_mart.data_migration.common.initialContext;
import jp.co.intra_mart.data_migration.common.read.CreateRowsException;
import jp.co.intra_mart.data_migration.common.read.Rows;
import jp.co.intra_mart.data_migration.common.read.database.DatabaseReader;
import jp.co.intra_mart.data_migration.common.table.ColumnInfo;
import jp.co.intra_mart.data_migration.common.table.GeneratorConstant;
import jp.co.intra_mart.data_migration.common.table.ISPGeneratorAdaptor;
import jp.co.intra_mart.data_migration.common.util.StringUtil;

public class ConferenceGenerator extends ISPGeneratorAdaptor {

	Rows rows = null;

	private static final ColumnInfo[] COLUMNSCINFO = {
		/* ISPT_CONFERENCE_INFO
		 * 
			1	cʃR[h (FK)	CONFERENCE_CLS_CD	VARCHAR2	20	0	Y		cʃR[h		
			2	cR[h		CONFERENCE_INFO_CD	VARCHAR2	20	0	Y	1	cR[h		
			3	XbhR[h			THREAD_CD			VARCHAR2	20	0	Y		ŏʃXbh̉cR[h		
			4	efR[h		PARENT_CD			VARCHAR2	20	0			ecR[h		
			5	^Cg				TITLE				VARCHAR2	255	0			͕		
			6	e					CONTENTS			VARCHAR2	2000	0		͕		
			7	HTMLRec			CONTENTS_HTML		VARCHAR2	2000	0		͕(HTML)		
			8	zM				NOTICE_CLS_CD		VARCHAR2	3	0			1:OCʁA2:[, 3:		
			9	zMJn			NOTICE_START_DATE	VARCHAR2	19	0			yyyy/mm/dd|hh:mm:ss		
			10	zMI			NOTICE_END_DATE		VARCHAR2	19	0			yyyy/mm/dd|hh:mm:ss		
			11	o^[UR[h			INSERT_USER_CD		VARCHAR2	50	0	Y		[UR[h		
			12	o^[U			INSERT_USER_NAME	VARCHAR2	128	0	Y		[U		
			13	o^				INSERT_DATE			VARCHAR2	19	0	Y		yyyy/mm/dd|hh:mm:ss		
			14	XV[UR[h			RECORD_USER_CD		VARCHAR2	50	0	Y		[UR[h		
			15	XV[U			RECORD_USER_NAME	VARCHAR2	128	0	Y		[U		
			16	XV				RECORD_DATE			VARCHAR2	19	0	Y		yyyy/mm/dd|hh:mm:ss		
	
		 */
		// cʃR[h
		new ColumnInfo("conference_cls_cd", "varchar2(20)", false, false, false, false), 
		// cR[h
		new ColumnInfo("conference_info_cd", "varchar2(20)", true, false, false, false), 
		// XbhR[h
		new ColumnInfo("thread_cd", "varchar2(20)", false, false, false, false), 
		// efR[h
		new ColumnInfo("parent_cd", "varchar2(20)", false, false, false, true), 
		// ^Cg
		new ColumnInfo("title", "varchar2(255)", false, false, false, true), 
		// e
		new ColumnInfo("contents", "varchar2(2000)", false, false, false, true), 
		// HTMLRec
		new ColumnInfo("contents_html", "varchar2(2000)", false, false, false, true), 
		// zM
		new ColumnInfo("notice_cls_cd", "varchar2(3)", false, false, false, true), 
		// zMJn
		new ColumnInfo("notice_start_date", "varchar2(19)", false, false, false, true), 
		// zMI
		new ColumnInfo("notice_end_date", "varchar2(19)", false, false, false, true), 
		// o^[UR[h
		new ColumnInfo("insert_user_cd", "varchar2(50)", false, false, false, false), 
		// o^[U
		new ColumnInfo("insert_user_name", "varchar2(128)", false, false, false, false), 
		// o^
		new ColumnInfo("insert_date", "varchar2(19)", false, false, false, false), 
		// XV[UR[h
		new ColumnInfo("record_user_cd", "varchar2(50)", false, false, false, false), 
		// XV[U
		new ColumnInfo("record_user_name", "varchar2(128)", false, false, false, false), 
		// XV
		new ColumnInfo("record_date", "varchar2(19)", false, false, false, false), 
	};

	public void createSQLFile(Writer out, Connection connection) throws IOException {

		DatabaseReader databaseReader = new DatabaseReader();

		PreparedStatement statement = null;
		StringBuffer sqlBuffer = new StringBuffer();
		// ISPT_BULLETIN_INFO f[^擾
		sqlBuffer.append("SELECT T1.conference_cls_cd, ");	// 1
		sqlBuffer.append("T1.conference_info_cd, ");		// 2
		sqlBuffer.append("T1.thread_cd, ");					// 3
		sqlBuffer.append("T1.parent_cd, ");					// 4
		sqlBuffer.append("T1.title, ");						// 5
		sqlBuffer.append("T1.contents, ");					// 6
		sqlBuffer.append("T1.contents_html, ");				// 7
		sqlBuffer.append("T1.notice_cls_cd, ");				// 8
		sqlBuffer.append("T1.notice_start_date, ");			// 9
		sqlBuffer.append("T1.notice_end_date, ");			// 10
		sqlBuffer.append("T1.insert_user_cd, ");			// 11
		sqlBuffer.append("T1.insert_user_name, ");			// 12
		sqlBuffer.append("T1.insert_date, ");				// 13
		sqlBuffer.append("T1.record_user_cd, ");			// 14
		sqlBuffer.append("T1.record_user_name, ");			// 15
		sqlBuffer.append("T1.record_date ");				// 16
		sqlBuffer.append("FROM ispt_conference_info T1");					

		try {
			statement = connection.prepareStatement(sqlBuffer.toString());
		} catch (SQLException e1) {
			// TODO Auto-generated catch block
			e1.printStackTrace();
		}
		try {
			rows =  databaseReader.read(connection, statement);
		} catch (CreateRowsException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (SQLException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		COLUMNS =  COLUMNSCINFO;
		String insertSQLFacility = createInsertBaseSQL();

		// ispt_bulletin_infõt@CC^[
		InsertFileWriter conferenceWriter = new InsertFileWriter();
		conferenceWriter.setTableName("ispt_conference_info");

		StringBuffer conferenceBuffer;

		for (int i = 1; i < rows.size()+1; i++) {
			
			conferenceBuffer = new StringBuffer();

			// insert
			conferenceBuffer.append(insertSQLFacility);
			
			// conference_cls_cd
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(1)) + ", ");
			
			// conference_info_cd
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(2)) + ", ");
			
			// thread_cd
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(3)) + ", ");
			
			// parent_cd
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(4)) + ", ");
			
			// title
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(5)) + ", ");
			
			// contents
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(6)) + ", ");
			
			// contents_html
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(7)) + ", ");
			
			// notice_cls_cd
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(8)) + ", ");
			
			// notice_start_date
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(9)) + ", ");
			
			// notice_end_date
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(10)) + ", ");
			
			// insert_user_cd
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(11)) + ", ");
			
			// insert_user_name
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(12)) + ", ");
			
			// insert_date
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(13)) + ", ");
			
			// record_user_cd
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(14)) + ", ");
			
			// record_user_name
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(15)) + ", ");
			
			// record_date
			conferenceBuffer.append(StringUtil.TrimNull(rows.getColumns(i).getString(16)) + ");\n");
			
			conferenceWriter.addRecord(conferenceBuffer.toString());

		}

		conferenceWriter.close();
	}

	ColumnInfo[] COLUMNS = null;

	public ColumnInfo[] getColumnInfos() {
		return COLUMNS;
	}

}
